"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var htmldom_service_1 = require("../../commons/services/htmldom.service");
var attr_class_1 = require("../../commons/extends/attr.class");
var toggle_directives_1 = require("../../commons/directives/toggle.directives");
var WEEK_DAY_NUM = 7;
var MIN_YEAR = 1000;
var MIN_MONTH = 1;
var MAX_MONTH = 12;
var DatepickerComponent = /** @class */ (function (_super) {
    __extends(DatepickerComponent, _super);
    function DatepickerComponent(html) {
        var _this = _super.call(this) || this;
        _this.html = html;
        _this.valueChange = new core_1.EventEmitter();
        _this.ticking = false;
        _this.datepickerStyle = { top: '0', left: '0', display: 'none', position: 'absolute' };
        // labels
        // labels
        _this.weekTitles = ['Mo', 'Tu', 'We', 'Th', 'Fr', 'Sa', 'Su'];
        _this.monthTitles = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'];
        // tody
        var date = new Date();
        _this.year = date.getFullYear();
        _this.month = date.getMonth() + 1;
        _this.day = date.getDate();
        // active day
        // active day
        _this.setValue();
        _this.show = false;
        return _this;
    }
    Object.defineProperty(DatepickerComponent.prototype, "days", {
        get: function () {
            var date = new Date(this.year, this.month, 0);
            var dayTotal = date.getDate();
            var days = new Array();
            date = new Date(this.year, this.month - 1, 1);
            var week = date.getDay() || WEEK_DAY_NUM;
            for (var i = 0; i < week - 1; i++) {
                days.push(0);
            }
            for (var i = 1; i <= dayTotal; i++) {
                days.push(i);
            }
            return days;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DatepickerComponent.prototype, "trList", {
        get: function () {
            var days = this.days;
            var groupNum = Math.ceil(days.length / WEEK_DAY_NUM);
            var trs = new Array();
            for (var i = 0; i < groupNum; i++) {
                trs[i] = new Array();
                for (var j = 0; j < WEEK_DAY_NUM; j++) {
                    trs[i][j] = days[i * WEEK_DAY_NUM + j] || 0;
                }
            }
            return trs;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DatepickerComponent.prototype, "yearList", {
        get: function () {
            var years = [];
            for (var i = 0; i < 3; i++) {
                years.push(this.year - 3 + i);
            }
            years.push(this.year);
            for (var i = 0; i < 3; i++) {
                years.push(this.year + 1 + i);
            }
            return years;
        },
        enumerable: true,
        configurable: true
    });
    DatepickerComponent.prototype.ngOnDestroy = function () {
        window.removeEventListener('scroll', this.autoHandle);
        window.removeEventListener('resize', this.autoHandle);
    };
    DatepickerComponent.prototype.getMonth = function (month) {
        return this.monthTitles[month - 1];
    };
    DatepickerComponent.prototype.setDay = function (day) {
        if (day <= 0) {
            return;
        }
        this.day = day;
        this.setValue();
        this.valueChange.emit(this.value);
        this.toggle();
    };
    DatepickerComponent.prototype.setValue = function () {
        this.value = this.year + "/" + this.month + "/" + this.day;
    };
    DatepickerComponent.prototype.isActiveDay = function (day) {
        return this.value === this.year + "/" + this.month + "/" + day;
    };
    DatepickerComponent.prototype.nextMonth = function () {
        if (this.month < MAX_MONTH) {
            this.month++;
        }
        else {
            this.year++;
            this.month = MIN_MONTH;
        }
    };
    DatepickerComponent.prototype.prevMonth = function () {
        if (this.month > MIN_MONTH) {
            this.month--;
        }
        else if (this.year > MIN_YEAR) {
            this.year--;
            this.month = MAX_MONTH;
        }
    };
    DatepickerComponent.prototype.nextYear = function () {
        this.year++;
    };
    DatepickerComponent.prototype.prevYear = function () {
        if (this.year > MIN_YEAR) {
            this.year--;
        }
    };
    DatepickerComponent.prototype.toggle = function () {
        this.show = !this.show;
        if (this.show) {
            if (!this.value) {
                this.value = this.year + "/" + this.month + "/" + this.day;
            }
            else {
                var date = this.value.split('/');
                this.year = parseInt(date[0], 10);
                this.month = parseInt(date[1], 10);
                this.day = parseInt(date[2], 10);
            }
            this.autoPosition();
        }
    };
    DatepickerComponent.prototype.bind = function (toggleDirective) {
        var _this = this;
        this.toggleDom = toggleDirective.dom;
        this.autoHandle = function () {
            if (!_this.ticking) {
                window.requestAnimationFrame(function () {
                    if (_this.show) {
                        _this.autoPosition();
                    }
                    _this.ticking = false;
                });
            }
            _this.ticking = true;
        };
        window.addEventListener('scroll', this.autoHandle, false);
        window.addEventListener('resize', this.autoHandle, false);
    };
    DatepickerComponent.prototype.autoPosition = function () {
        var _this = this;
        setTimeout(function () {
            var padPositon = _this.html.getPosition(_this.pad.nativeElement);
            var position = _this.html.getPosition(_this.toggleDom);
            var height = _this.html.getHeight(_this.toggleDom);
            _this.datepickerStyle.display = 'none';
            _this.datepickerStyle.left = position.x - padPositon.x + 'px';
            _this.datepickerStyle.top = height + position.y + 7.5 + 'px';
            var top = height + position.y + 7.5 + 380;
            if (window.innerHeight < top) {
                top = window.innerHeight - 380 - 7.5;
            }
            else {
                top = position.y + height + 7.5;
            }
            _this.datepickerStyle.top = top - padPositon.y + 'px';
            _this.datepickerStyle.display = '';
        });
    };
    DatepickerComponent.prototype.tryClose = function ($event) {
        if ($event.target === this.pad.nativeElement) {
            this.toggle();
        }
    };
    DatepickerComponent.prototype.trackByFn = function (item) {
        return item.length;
    };
    DatepickerComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'ts-datepicker',
                    templateUrl: './datepicker.component.html',
                    styleUrls: ['./datepicker.component.css'],
                    exportAs: 'tsDatepicker'
                },] },
    ];
    /** @nocollapse */
    DatepickerComponent.ctorParameters = function () { return [
        { type: htmldom_service_1.HtmlDomService, },
    ]; };
    DatepickerComponent.propDecorators = {
        "weekTitles": [{ type: core_1.Input },],
        "monthTitles": [{ type: core_1.Input },],
        "value": [{ type: core_1.Input },],
        "activeClass": [{ type: core_1.Input },],
        "toggleTarget": [{ type: core_1.Input },],
        "valueChange": [{ type: core_1.Output },],
        "pad": [{ type: core_1.ViewChild, args: ['pad',] },],
        "datepicker": [{ type: core_1.ViewChild, args: ['datepicker',] },],
    };
    return DatepickerComponent;
}(attr_class_1.DomAttr));
exports.DatepickerComponent = DatepickerComponent;
//# sourceMappingURL=datepicker.component.js.map