"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var toggle_directives_1 = require("../../commons/directives/toggle.directives");
var DropdownDirective = /** @class */ (function () {
    function DropdownDirective(elementRef) {
        this.elementRef = elementRef;
        this.dropup = null;
        this.class = 'btn-group';
    }
    DropdownDirective.prototype.onDocumentClick = function (dom) {
        if (!this.isClose() && !this.elementRef.nativeElement.contains(dom)) {
            this.dismiss();
        }
    };
    DropdownDirective.prototype.ngOnInit = function () {
        this.class += (this.dropup === null ? '' : ' dropup');
    };
    DropdownDirective.prototype.ngAfterViewInit = function () {
        var _this = this;
        this.toggleDirective.target = this;
        this.toggleDirective.dom.type = 'button';
        this.dropMenuDirective.onClick = function () {
            _this.toggle();
        };
    };
    DropdownDirective.prototype.toggle = function () {
        this.dropMenuDirective.dom.style.display === 'block' ? this.dismiss() : this.present();
    };
    DropdownDirective.prototype.isClose = function () {
        return this.dropMenuDirective.dom.style.display !== 'block';
    };
    DropdownDirective.prototype.present = function () {
        var btn = this.toggleDirective.elementRef.nativeElement;
        var btnSize = [btn.clientWidth, btn.clientHeight];
        this.dropMenuDirective.setShow(this.dropup !== null, btnSize);
    };
    DropdownDirective.prototype.dismiss = function () {
        this.dropMenuDirective.setHidden();
    };
    DropdownDirective.decorators = [
        { type: core_1.Directive, args: [{
                    selector: "[tsDropdown]",
                    exportAs: 'tsDropdown'
                },] },
    ];
    /** @nocollapse */
    DropdownDirective.ctorParameters = function () { return [
        { type: core_1.ElementRef, },
    ]; };
    DropdownDirective.propDecorators = {
        "dropup": [{ type: core_1.Input },],
        "toggleDirective": [{ type: core_1.ContentChild, args: [core_1.forwardRef(function () { return toggle_directives_1.ToggleDirective; }),] },],
        "dropMenuDirective": [{ type: core_1.ContentChild, args: [core_1.forwardRef(function () { return DropMenuDirective; }),] },],
        "class": [{ type: core_1.HostBinding, args: ['class',] },],
        "onDocumentClick": [{ type: core_1.HostListener, args: ['document:click', ['$event.target'],] },],
    };
    return DropdownDirective;
}());
exports.DropdownDirective = DropdownDirective;
var DropMenuDirective = /** @class */ (function () {
    function DropMenuDirective(elementRef) {
        this.elementRef = elementRef;
        this.class = 'dropdown-menu';
        this.left = null;
    }
    DropMenuDirective.prototype.ngAfterViewInit = function () {
        this.dom = this.elementRef.nativeElement;
        this.dom.style.top = '0';
        this.dom.style.left = '0';
    };
    DropMenuDirective.prototype.setPostion = function (dropup, btnSize) {
        if (dropup === void 0) { dropup = false; }
        var offsetLeft = 0;
        if (this.left !== null) {
            offsetLeft = btnSize[0] - this.dom.clientWidth;
        }
        if (dropup !== null && dropup !== false) {
            this.dom.style.transform = "translate3d(" + offsetLeft + "px, -" + (this.dom.clientHeight + 4) + "px, 0px)";
        }
        else {
            this.dom.style.transform = "translate3d(" + offsetLeft + "px, " + (btnSize[1] + 4) + "px, 0px)";
        }
    };
    DropMenuDirective.prototype.setShow = function (dropup, btnSize) {
        if (dropup === void 0) { dropup = false; }
        this.dom.style.display = 'block';
        this.setPostion(dropup, btnSize);
    };
    DropMenuDirective.prototype.setHidden = function () {
        this.dom.style.display = '';
    };
    DropMenuDirective.decorators = [
        { type: core_1.Directive, args: [{
                    selector: "[tsDropMenu]",
                },] },
    ];
    /** @nocollapse */
    DropMenuDirective.ctorParameters = function () { return [
        { type: core_1.ElementRef, },
    ]; };
    DropMenuDirective.propDecorators = {
        "left": [{ type: core_1.Input },],
        "class": [{ type: core_1.HostBinding, args: ['class',] },],
        "onClick": [{ type: core_1.HostListener, args: ['click',] },],
    };
    return DropMenuDirective;
}());
exports.DropMenuDirective = DropMenuDirective;
//# sourceMappingURL=dropdown.directive.js.map